@@ -12,18 +12,19 @@ def main():
     # parser.add_argument('-c', '--config', action='store_true', help='show instruments and remote service configurations.')
     parser.add_argument('-f', '--fakeapi', action='store_true',
                         help='fake API to avoid remote connection (dev. only).')
-    parser.add_argument('-u', '--username', type=str,
-                        help='use another user login in history\'s comments.')
     parser.add_argument('-v', '--verbose', action='store_true', help='Verbose')
+    parser.add_argument('-c', '--createprefs', action='store_true', help='Create preferences file')
 
     args = parser.parse_args()
 
     from . import A2p2Client
+
+    if args.createprefs:
+        A2p2Client.createPreferencesFile()
+        exit()
+
     try:
         with A2p2Client(args.fakeapi) as a2p2c:
-            if args.username:
-                a2p2c.setUsername(args.username)
-
             # if  args.config:
             #    print(a2p2c)
             # else:
